==> mysql-connector-odbc-8.0.22-src.tar.gz: mysql-connector-odbc-8.0.22-src/setupgui/windows/resource.h <==
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2006, 2018, Oracle and/or its affiliates. All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation. The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/ODBC, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by odbcdialogparams.rc
//
#define IDR_RT_MANIFEST1                1
#define IDC_MYICON                      2
#define IDCANCEL2                       3
#define IDHELP2                         11
#define IDD_DIALOG_DIALOG               102
#define IDS_APP_TITLE                   103
#define IDD_ABOUTBOX                    103
#define IDM_ABOUT                       104
#define IDM_EXIT                        105
#define IDI_DIALOG                      107
#define IDI_SMALL                       108
#define IDC_DIALOG                      109
#define IDR_MAINFRAME                   128
#define IDD_DIALOG1                     129
#define IDB_LOGO                        130
#define IDD_TAB1                        131
#define IDD_TAB2                        132
#define IDD_TAB3                        133
#define IDD_TAB4                        134
#define IDD_TAB5                        136
#define IDD_TAB6                        137
#define IDC_LOGO                        1000
#define IDC_EDIT_DRVNAME                1004
#define IDC_EDIT_DRVDESC                1005
#define IDC_EDIT_SRVNAME                1007
#define IDC_EDIT_PORT                   1008
#define IDC_EDIT_USERNAME               1009
#define IDC_EDIT                        1010
#define IDC_EDIT_PASSWORD               1010
#define IDC_EDIT_DBNAME                 1011
#define IDC_BUTTON_DETAILS              1012
#define IDC_TAB1                        1013
#define IDC_COMBO1                      1022
#define IDC_SSLKEYCHOOSER               1023
#define IDC_SSLCERTCHOOSER              1025
#define IDC_SSLCACHOOSER                1026
#define IDC_SSLCAPATHCHOOSER            1027
#define IDC_CHECK_sslverify             1028
#define IDC_CHECK_min_date_to_zero      1029
#define IDC_RSAKEYCHOOSER               1030
#define IDC_EDIT_drvname                10000
#define IDC_EDIT_name                   10000
#define IDC_EDIT_drvdesc                10001
#define IDC_EDIT_description            10001
#define IDC_EDIT_srvname                10002
#define IDC_EDIT_server                 10002
#define IDC_EDIT_port                   10003
#define IDC_EDIT_username               10004
#define IDC_EDIT_uid                    10004
#define IDC_EDIT_password               10005
#define IDC_EDIT_pwd                    10005
#define IDC_EDIT_dbname                 10006
#define IDC_EDIT_database               10006
#define IDC_CHECK_dont_optimize_column_width 10007
#define IDC_CHECK_return_matching_rows  10008
#define IDC_CHECK_allow_big_results     10009
#define IDC_CHECK_use_compressed_protocol 10010
#define IDC_CHECK_change_bigint_columns_to_int 10011
#define IDC_CHECK_safe                  10012
#define IDC_CHECK_auto_reconnect        10013
#define IDC_CHECK_auto_increment_null_search 10014
#define IDC_CHECK_dont_prompt_upon_connect 10015
#define IDC_CHECK_dynamic_cursor        10016
#define IDC_CHECK_user_manager_cursor   10018
#define IDC_CHECK_dont_use_set_locale   10019
#define IDC_CHECK_pad_char_to_full_length 10020
#define IDC_CHECK_dont_cache_result     10021
#define IDC_CHECK_return_table_names_for_SqlDescribeCol 10022
#define IDC_CHECK_pad_char_to_full_length2 10022
#define IDC_CHECK_zero_date_to_min      10022
#define IDC_CHECK_ignore_space_after_function_names 10023
#define IDC_CHECK_no_catalog            10025
#define IDC_CHECK_read_options_from_mycnf 10026
#define IDC_CHECK_disable_transactions  10027
#define IDC_CHECK_force_use_of_forward_only_cursors 10028
#define IDC_CHECK_allow_multiple_statements 10029
#define IDC_CHECK_limit_column_size     10030
#define IDC_EDIT_sslca                  10031
#define IDC_EDIT_sslcapath              10032
#define IDC_EDIT_sslcert                10033
#define IDC_EDIT_sslkey                 10034
#define IDC_EDIT_sslcipher              10035
#define IDC_CHECK_handle_binary_as_char 10036
#define IDC_CHECK_save_queries          10037
#define IDC_EDIT_charset                10038
#define IDC_EDIT_initstmt               10039
#define IDC_CHECK_clientinteractive     10040
#define IDC_CHECK_no_information_schema 10041
#define IDC_EDIT_socket                 10042
#define IDC_RADIO_tcp                   10043
#define IDC_RADIO_pipe                  10044
#define IDC_CHECK_cursor_prefetch_active 10045
#define IDC_EDIT_cursor_prefetch_number 10046
#define IDC_CHECK_no_ssps               10047
#define IDC_CHECK_can_handle_exp_pwd    10048
#define IDC_CHECK_enable_cleartext_plugin 10049
#define IDC_CHECK_default_bigint_bind_str 10050
#define IDC_EDIT_rsakey                 10051
#define IDC_EDIT_plugin_dir             10053
#define IDC_EDIT_default_auth           10054
#define IDC_CHOOSER_plugin_dir          10055
#define IDC_CHECK_no_date_overflow      10057
#define IDC_CHECK_no_tls_1              10058
#define IDC_CHECK_no_tls_1_1            10059
#define IDC_CHECK_no_tls_1_2            10060
#define IDC_EDIT_sslmode                10061
#define IDC_CHECK_get_server_public_key 10062
#define IDC_CHECK_enable_local_infile   10063
#define IDC_CHECK_enable_dns_srv        10064
#define IDC_CHECK_multi_host            10065
#define IDC_EDIT_load_data_local_dir    10066
#define IDC_CHOOSER_load_data_local_dir 10067
#define IDC_BUTTON_TEST                 11014
#define IDC_BUTTON_HELP                 11015
#define IDC_STATIC                      -1

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        137
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1030
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif

==> mysql-connector-odbc-8.0.27-src.tar.gz: mysql-connector-odbc-8.0.27-src/setupgui/windows/resource.h <==
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2006, 2018, Oracle and/or its affiliates. All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation. The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/ODBC, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by odbcdialogparams.rc
//
#define IDR_RT_MANIFEST1                1
#define IDC_MYICON                      2
#define IDCANCEL2                       3
#define IDHELP2                         11
#define IDD_DIALOG_DIALOG               102
#define IDS_APP_TITLE                   103
#define IDD_ABOUTBOX                    103
#define IDM_ABOUT                       104
#define IDM_EXIT                        105
#define IDI_DIALOG                      107
#define IDI_SMALL                       108
#define IDC_DIALOG                      109
#define IDR_MAINFRAME                   128
#define IDD_DIALOG1                     129
#define IDB_LOGO                        130
#define IDD_TAB1                        131
#define IDD_TAB2                        132
#define IDD_TAB3                        133
#define IDD_TAB4                        134
#define IDD_TAB5                        136
#define IDD_TAB6                        137
#define IDD_TAB7                        138
#define IDC_LOGO                        1000
#define IDC_EDIT_DRVNAME                1004
#define IDC_EDIT_DRVDESC                1005
#define IDC_EDIT_SRVNAME                1007
#define IDC_EDIT_PORT                   1008
#define IDC_EDIT_USERNAME               1009
#define IDC_EDIT                        1010
#define IDC_EDIT_PASSWORD               1010
#define IDC_EDIT_DBNAME                 1011
#define IDC_BUTTON_DETAILS              1012
#define IDC_TAB1                        1013
#define IDC_COMBO1                      1022
#define IDC_SSLKEYCHOOSER               1023
#define IDC_SSLCERTCHOOSER              1025
#define IDC_SSLCACHOOSER                1026
#define IDC_SSLCAPATHCHOOSER            1027
#define IDC_CHECK_sslverify             1028
#define IDC_CHECK_min_date_to_zero      1029
#define IDC_RSAKEYCHOOSER               1030
#define IDC_EDIT_drvname                10000
#define IDC_EDIT_name                   10000
#define IDC_EDIT_drvdesc                10001
#define IDC_EDIT_description            10001
#define IDC_EDIT_srvname                10002
#define IDC_EDIT_server                 10002
#define IDC_EDIT_port                   10003
#define IDC_EDIT_username               10004
#define IDC_EDIT_uid                    10004
#define IDC_EDIT_password               10005
#define IDC_EDIT_pwd                    10005
#define IDC_EDIT_dbname                 10006
#define IDC_EDIT_database               10006
#define IDC_CHECK_dont_optimize_column_width 10007
#define IDC_CHECK_return_matching_rows  10008
#define IDC_CHECK_allow_big_results     10009
#define IDC_CHECK_use_compressed_protocol 10010
#define IDC_CHECK_change_bigint_columns_to_int 10011
#define IDC_CHECK_safe                  10012
#define IDC_CHECK_auto_reconnect        10013
#define IDC_CHECK_auto_increment_null_search 10014
#define IDC_CHECK_dont_prompt_upon_connect 10015
#define IDC_CHECK_dynamic_cursor        10016
#define IDC_CHECK_user_manager_cursor   10018
#define IDC_CHECK_dont_use_set_locale   10019
#define IDC_CHECK_pad_char_to_full_length 10020
#define IDC_CHECK_dont_cache_result     10021
#define IDC_CHECK_return_table_names_for_SqlDescribeCol 10022
#define IDC_CHECK_pad_char_to_full_length2 10022
#define IDC_CHECK_zero_date_to_min      10022
#define IDC_CHECK_ignore_space_after_function_names 10023
#define IDC_CHECK_no_catalog            10025
#define IDC_CHECK_no_schema             10069
#define IDC_CHECK_read_options_from_mycnf 10026
#define IDC_CHECK_disable_transactions  10027
#define IDC_CHECK_force_use_of_forward_only_cursors 10028
#define IDC_CHECK_allow_multiple_statements 10029
#define IDC_CHECK_limit_column_size     10030
#define IDC_EDIT_sslca                  10031
#define IDC_EDIT_sslcapath              10032
#define IDC_EDIT_sslcert                10033
#define IDC_EDIT_sslkey                 10034
#define IDC_EDIT_sslcipher              10035
#define IDC_CHECK_handle_binary_as_char 10036
#define IDC_CHECK_save_queries          10037
#define IDC_EDIT_charset                10038
#define IDC_EDIT_initstmt               10039
#define IDC_CHECK_clientinteractive     10040
#define IDC_CHECK_no_information_schema 10041
#define IDC_EDIT_socket                 10042
#define IDC_RADIO_tcp                   10043
#define IDC_RADIO_pipe                  10044
#define IDC_CHECK_cursor_prefetch_active 10045
#define IDC_EDIT_cursor_prefetch_number 10046
#define IDC_CHECK_no_ssps               10047
#define IDC_CHECK_can_handle_exp_pwd    10048
#define IDC_CHECK_enable_cleartext_plugin 10049
#define IDC_CHECK_default_bigint_bind_str 10050
#define IDC_EDIT_rsakey                 10051
#define IDC_EDIT_plugin_dir             10053
#define IDC_EDIT_default_auth           10054
#define IDC_CHOOSER_plugin_dir          10055
#define IDC_CHECK_no_date_overflow      10057
#define IDC_CHECK_no_tls_1              10058
#define IDC_CHECK_no_tls_1_1            10059
#define IDC_CHECK_no_tls_1_2            10060
#define IDC_CHECK_no_tls_1_3            10061
#define IDC_EDIT_sslmode                10062
#define IDC_CHECK_get_server_public_key 10063
#define IDC_CHECK_enable_local_infile   10064
#define IDC_CHECK_enable_dns_srv        10065
#define IDC_CHECK_multi_host            10066
#define IDC_EDIT_load_data_local_dir    10067
#define IDC_CHOOSER_load_data_local_dir 10068
#define IDC_EDIT_pwd2                   10069
#define IDC_EDIT_pwd3                   10070
#define IDC_EDIT_oci_config_file        10071
#define IDC_CHOOSER_oci_config_file     10072
#define IDC_BUTTON_TEST                 11014
#define IDC_BUTTON_HELP                 11015
#define IDC_STATIC                      -1

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        137
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1030
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif
